Functions
- export_
lines - Render shell
exportlines that can beeval’d by the parent shell. Values are single-quoted and embedded quotes are escaped for the shell.
export lines that can be eval’d by the parent shell.
Values are single-quoted and embedded quotes are escaped for the shell.